#ifndef _KYSEC_UDISK_H
#define _KYSEC_UDISK_H

#define UDISK_CHAR_MID_LEN	128
#define UDISK_CHAR_MAX_LEN	256
#define UDISK_HASH_SIZE		64
#define UDISK_IS_GLOBAL		1
#define UDISK_NOT_GLOBAL 	0


enum kysec_udisk_perm {
	DEVICE_ENABLE = 1,
	DEVICE_DISABLE,
	DEVICE_RO = 5,
	DEVICE_PERM_MAX
};

struct kysec_udisk_policy_kernel {
	unsigned int pid;
	unsigned int vid;
	int global;
	int perm;
	char hash[UDISK_HASH_SIZE + 1];
};

struct kysec_udisk_policy {
	unsigned int pid;
	unsigned int vid;
	int global;
	int perm;
	char path[UDISK_CHAR_MAX_LEN];
	char brand[UDISK_CHAR_MID_LEN];
	char model[UDISK_CHAR_MID_LEN];
};

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 添加u盘外发策略
 * @param {kysec_udisk_policy} *data
 * @param {int} count
 * @return {*}
 */
int kysec_udisk_add_policy(struct kysec_udisk_policy *data, int count);

/**
 * @brief 删除u盘外发策略
 * @param {kysec_udisk_policy} *data
 * @param {int} count
 * @return {*}
 */
int kysec_udisk_remove_policy(struct kysec_udisk_policy *data, int count);

/**
 * @brief 获取所有的u盘外发策略
 * @param {int} [out] *count
 * @return {*}
 */
struct kysec_udisk_policy *kysec_udisk_get_all_policies(int *count);

/**
 * @brief 同步策略到内核
 * @param {kysec_udisk_policy} *data
 * @return {*}
 */
void kysec_udisk_communicate_kernel(int op_type, struct kysec_udisk_policy data);

#ifdef __cplusplus
}
#endif

#endif /* _KYSEC_UDISK_H */
